#coding=utf8

# This file is part of CloudControl.
#
# CloudControl is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# CloudControl is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with CloudControl.  If not, see <http://www.gnu.org/licenses/>.

'''
CloudControl CLI RPC Handler
'''

from cloudcontrol.cli import version
from cloudcontrol.cli.exception import *
from cloudcontrol.cli.printer import Printer, color
from sjrpc.utils import RpcHandler

import os, os.path
import subprocess
import platform


class CliHandler(RpcHandler):
    '''Handle RPC incoming request'''

    def quit(self, rpc=None):
        '''Call back function on server disconnect'''
        Printer().warn("Disconnected from server!")

    def wall(self, sender, message):
        '''Receive a wall from the server'''
        Printer().out("\n\nWall from: %s\n\n%s\n\n" % (sender, message))

    def get_tags(self, tags):
        '''Return a dict of local tags'''
        ans = {}
        for tag in tags:
            method = "_get_tag_%s" % tag
            if hasattr(self, method):
                ans[tag] = getattr(self, method)()
        return ans

    def _get_tag_version(self):
        '''Return tag version'''
        return version

    def _get_tag_os(self):
        '''Return Operating system tag'''
        return platform.system().lower()

    def _get_tag_uname(self):
        '''Return uname output'''
        try:
            p = subprocess.Popen(["uname", "-a"], close_fds=True, shell=False, stdout=subprocess.PIPE)
            return  p.communicate()[0].rstrip("\n")
        except Exception:
            return ""

    def _get_tag_uptime(self):
        '''Return uptime output'''
        try:
            return int(float(open("/proc/uptime", "r").readline().split()[0]))
        except Exception:
            return ""
